@@ -30,6 +30,7 @@ from neuralspace.constants import (
     END_INDEX,
     ENTITIES,
     ENTITY_ACC,
+    ENTITY_TYPE,
     ERROR,
     EXAMPLE,
     EXAMPLE_ID,
@@ -49,6 +50,7 @@ from neuralspace.constants import (
     LANGUAGE,
     LANGUAGES,
     LAST_STATUS_UPDATED,
+    LIST_ENTITY_URL,
     MESSAGE,
     METRICS,
     MODEL_ID,
@@ -82,6 +84,7 @@ from neuralspace.constants import (
     REPLICAS,
     SAD_SMILEY,
     SAND_CLOCK,
+    SAVED,
     SEARCH,
     SOUP,
     START_INDEX,
@@ -103,6 +106,7 @@ from neuralspace.nlu.constants import (
     C_INITIATED,
     C_QUEUED,
     C_TIMED_OUT,
+    C_TRAINING,
     CREATE_EXAMPLE_URL,
     CREATE_PROJECT_URL,
     DELETE_EXAMPLE_URL,
@@ -361,7 +365,7 @@ def get_training_status_colour(status: Text) -> Text:
     if status == COMPLETED:
         return C_COMPLETED
     if status == TRAINING:
-        return C_COMPLETED
+        return C_TRAINING
     elif status == FAILED:
         return C_FAILED
     elif status == TIMED_OUT:
@@ -372,6 +376,8 @@ def get_training_status_colour(status: Text) -> Text:
         return C_INITIATED
     elif status == QUEUED:
         return C_QUEUED
+    elif status == SAVED:
+        return C_COMPLETED
 
 
 def print_models_table(models: Dict[Text, Any], verbose: bool):
@@ -447,7 +453,7 @@ async def list_models(
         if is_success_status(response.status):
             print_models_table(json_response, verbose)
             console.print(
-                f"{FAST_FORWARD} To deploy the model: [orange4]{DEPLOY_MODEL_COMMAND}{DARK_ORANGE_END}"
+                f"[orange4]{FAST_FORWARD} To deploy the model: [/orange4]{DEPLOY_MODEL_COMMAND}{DARK_ORANGE_END}"
             )
         else:
             console.print(f"> {ERROR} {CROSS} Failed to list models")
@@ -718,7 +724,7 @@ async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
     console.print(
         f"> {INFO} {PEN_AND_PAPER} Parsing text: {input_text}, using Model ID: {model_id}"
     )
-    payload = {MODEL_ID: model_id, DATA: {TEXT: input_text}}
+    payload = {MODEL_ID: model_id, TEXT: input_text}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
 
@@ -740,3 +746,42 @@ async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
                 f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response['message']}{RED_END} "'''
             )
     return json_response
+
+
+async def get_entity_list_for_cli(
+    entity_type: Text, language: Text, pagesize=1, count=None
+):
+    if count is None:
+        print(pagesize)
+        payload = {
+            FILTER: {ENTITY_TYPE: entity_type, LANGUAGE: language},
+            SEARCH: "",
+            PAGE_NUMBER: 1,
+            PAGE_SIZE: pagesize,
+        }
+    else:
+        payload = {
+            FILTER: {ENTITY_TYPE: entity_type, LANGUAGE: language},
+            SEARCH: "",
+            PAGE_NUMBER: 1,
+            PAGE_SIZE: int(count),
+        }
+    HEADERS = copy(COMMON_HEADERS)
+    HEADERS[AUTHORIZATION] = get_auth_token()
+
+    async with get_async_http_session().post(
+        url=f"{neuralspace_url()}/{LIST_ENTITY_URL}",
+        data=json.dumps(payload, ensure_ascii=False),
+        headers=HEADERS,
+    ) as response:
+        json_response = await response.json(encoding="utf-8")
+        if is_success_status(response.status):
+            if count is None:
+                count = json_response[DATA][COUNT]
+                return int(count)
+            else:
+                entities_supported = [
+                    data["entity"] for data in json_response[DATA][ENTITIES]
+                ]
+                return entities_supported
+        return json_response
