@@ -1,6 +1,5 @@
 import asyncio
 import json
-import os
 import typing
 from contextvars import Context
 from inspect import Parameter
@@ -9,11 +8,14 @@ from typing import List, Text
 
 import click
 import randomname
-from rasa.shared.importers.utils import training_data_from_paths
 from rich.console import Console
 
 from neuralspace.apis import get_async_http_session
 from neuralspace.constants import (
+    BAG,
+    ERROR,
+    GREEN_TICK,
+    INFO,
     NAME_GENERATOR_CONFIG,
     NER_TYPES,
     ORANGE3_END,
@@ -37,7 +39,6 @@ from neuralspace.nlu.apis import (
     wait_till_training_completes,
 )
 from neuralspace.nlu.constants import SUPPORTED_LANGUAGES, TRAINING_PROGRESS
-from neuralspace.nlu.converters.rasaconverter import RasaConverter
 from neuralspace.utils import get_entity_list, print_logo, setup_logger
 
 console = Console()
@@ -56,6 +57,9 @@ class MappingClass(click.ParamType):
         total_entity_mapping = []
         for entities in list_of_entity_mapping:
             total_entity_mapping.append(entities.split(":"))
+        entity_mapping = dict()
+        for entity in total_entity_mapping:
+            entity_mapping[entity[0]] = entity[1]
         for entities in total_entity_mapping:
             try:
                 assert len(entities) == 2
@@ -65,7 +69,7 @@ class MappingClass(click.ParamType):
                     f"{ORANGE3_START}'your_entity_name:ns_entity_name,your_entity_name...'{ORANGE3_END}"
                 )
                 return False
-        return total_entity_mapping
+        return entity_mapping
 
 
 @click.group(name="nlu")
@@ -117,46 +121,66 @@ def nlu_get_languages(log_level: Text):
     "-t",
     "--data-type",
     type=click.Choice(["train", "test"], case_sensitive=True),
+    default="train",
     help="you can decide whether you want it as test or train data",
 )
 @click.option(
     "-d",
-    "--dataset-path",
+    "--input-path",
     required=True,
     help="Name of the folder in which the dataset files are in",
 )
+@click.option(
+    "-o",
+    "--output-path",
+    required=True,
+    help="Name of the folder in which the converted dataset files want to be stored",
+)
 def converter(
     from_platform: Text,
     auto_tag_entities: bool,
     language: Text,
     entity_mapping: List,
-    dataset_path: Text,
-    dataset_name: Text,
+    input_path: Text,
+    data_type: Text,
+    output_path: Text,
 ):
     if entity_mapping is not False:
         if from_platform == "rasa":
-            convert = RasaConverter(language)
-            rasa_data = training_data_from_paths([dataset_path], language=language)
-            lookup_data = convert.lookup_converter(rasa_data.lookup_tables)
-            regex_data = convert.regex_converter(rasa_data.regex_features)
-            synonym_data = convert.synonym_converter(rasa_data.entity_synonyms)
-            training_data = convert.training_data_converter(rasa_data)
-            directory_to_save_files = os.path.join(
-                os.getcwd(), f"neuralspace_{dataset_name}"
+            from neuralspace.nlu.converters.rasaconverter import RasaConverter
+
+            converter = RasaConverter(
+                language=language,
+                entity_mapping=entity_mapping,
+                auto_tag_entities=auto_tag_entities,
             )
-            os.mkdir(directory_to_save_files)
-            with open(os.path.join(directory_to_save_files, "lookup.json"), "w") as f:
-                json.dump(lookup_data, f)
-            with open(os.path.join(directory_to_save_files, "regex.json"), "w") as f:
-                json.dump(regex_data, f)
-            with open(os.path.join(directory_to_save_files, "synonym.json"), "w") as f:
-                json.dump(synonym_data, f)
-            with open(os.path.join(directory_to_save_files, "nlu.json"), "w") as f:
-                json.dump(training_data, f)
-        elif from_platform == "dialogflow":
-            pass
+            converter.convert(
+                input_path=input_path, output_path=output_path, type_of_data=data_type
+            )
+            console.print(
+                f"> {GREEN_TICK} SUCCESS Your {from_platform} dataset is now converted to Neuralspace-platform data"
+            )
+            console.print(
+                f"> {INFO} Converted dataset is {BAG} stored in: {output_path}"
+            )
+        else:
+            from neuralspace.nlu.converters.dialogflowconverter import (
+                DialogflowConverter,
+            )
+
+            converter = DialogflowConverter(
+                language=language,
+                entity_mapping=entity_mapping,
+                auto_tag_entities=auto_tag_entities,
+            )
+            converter.convert(
+                input_path=input_path, output_path=output_path, type_of_data=data_type
+            )
+
     else:
-        pass
+        console.print(
+            f"{ERROR} There is some error in the entity mapping you have given"
+        )
 
 
 @nlu.command(name="create-project")
